@@ -79,6 +79,12 @@ class Server(object):
         if res['ok']:
             return Database(self, dbname)
         return res['ok']
+
+    def get_or_create_db(self, dbname):
+        try:
+            return self[dbname]
+        except ResourceNotFound:
+            return self.create_db(dbname)
         
     def delete_db(self, dbname):
         if "/" in dbname:
@@ -164,6 +170,13 @@ class Database(object):
     def compact(self):
         """ compact database"""
         res = self.res.post('/_compact')
+
+    def flush(self):
+        _design_docs = [self[i["id"]] for i in self.all_docs(startkey="_design", endkey="_design/"+u"\u9999")]
+        self.server.delete_db(self.dbname)
+        self.server.create_db(self.dbname)
+        [i.pop("_rev") for i in _design_docs]
+        self.bulk_save( _design_docs )
         
     def doc_exist(self, docid):
         """Test if document exist in database
@@ -427,7 +440,7 @@ class Database(object):
     iter_documents = documents    
 
     def put_attachment(self, doc, content, name=None, 
-            content_type=None, content_length=None):
+            content_type=None, content_length=None, chunked=True):
         """ Add attachement to a document.
 
         :param doc: dict, document object
@@ -461,9 +474,13 @@ class Database(object):
 
         headers = {}
         headers.setdefault('Content-Type', 'text/plain')
+        
+        content = content or ''
+        if content and chunked:
+            headers.setdefault("Transfer-Encoding", "chunked")
 
         if name is None:
-            if hasattr('content', name):
+            if hasattr(content, "name"):
                 name = content.name
             else:
                 raise InvalidAttachment('You should provid a valid attachment name')
