@@ -32,11 +32,11 @@ from couchdbkit.resource import ResourceNotFound
 
 __all__ = ['ReservedWordError', 'ALLOWED_PROPERTY_TYPES', 'DocumentSchema', 
         'SchemaProperties', 'DocumentBase', 'QueryMixin', 'AttachmentMixin', 
-        'Document']
+        'Document', 'StaticDocument']
 
-_RESERVED_WORDS = ['_id', '_rev', '$schema']
+_RESERVED_WORDS = ['_id', '_rev', '$schema', 'type']
 
-_NODOC_WORDS = ['doc_type','id', 'rev']
+_NODOC_WORDS = ['doc_type','id', 'rev', 'type']
 
 
 ALLOWED_PROPERTY_TYPES = set([
@@ -434,20 +434,36 @@ class DocumentBase(DocumentSchema):
         self._doc.update({'_id': doc['_id'], '_rev': doc['_rev']})
         
     store = save
+
+    @classmethod
+    def bulk_save(cls, docs):
+        """ Save multiple documents in database.
+            
+        :params docs: list of couchdbkit.schema.Document instance
+        """
+        if cls._db is None:
+            raise TypeError("doc database required to save document")
+        docs_to_save= [doc._doc for doc in docs if doc._doc_type == cls._doc_type]
+        if not len(docs_to_save) == len(docs):
+            raise ValueError("one of your documents does not have the correct type")
+        cls._db.bulk_save(docs_to_save)
     
     @classmethod
-    def get(cls, docid, rev=None, db=None):
+    def get(cls, docid, rev=None, db=None, dynamic_properties=True):
         if db is not None:
             cls._db = db
+        cls._allow_dynamic_properties = dynamic_properties
         if cls._db is None:
             raise TypeError("doc database required to save document")
         return cls._db.get(docid, rev=rev, wrapper=cls.wrap)
         
     @classmethod
-    def get_or_create(cls, docid=None, db=None):
+    def get_or_create(cls, docid=None, db=None, dynamic_properties=True):
         if db is not None:
             cls._db = db
-                
+               
+        cls._allow_dynamic_properties = dynamic_properties
+        
         if cls._db is None:    
             raise TypeError("doc database required to save document")
             
@@ -516,26 +532,23 @@ class QueryMixin(object):
     """ Mixin that add query methods """
     
     @classmethod
-    def view(cls, view_name, wrapper=None, **params):
-        """ Get documents associated to a view.
-        Results of view are automatically wrapped
-        to Document object.
-
-        :params view_name: str, name of view
-        :params params:  params of view
-
-        :return: :class:`simplecouchdb.core.ViewResults` instance. All
-        results are wrapped to current document instance.
-        """
+    def __view(cls, view_type=None, data=None, wrapper=None, 
+    dynamic_properties=True, **params):
         def default_wrapper(row):
             data = row.get('value')
             docid = row.get('id')
+
             if not data or data is None:
                 doc = row.get('doc', False)
                 if doc:
                     return cls.wrap(doc)
                 return row
-            data['_id'] = row.get('id')
+                
+            if not isinstance(data, dict) or not docid:
+                return row
+                
+            data['_id'] = docid
+            cls._allow_dynamic_properties = dynamic_properties
             obj = cls.wrap(data)
             return obj
         
@@ -548,10 +561,32 @@ class QueryMixin(object):
             raise TypeError("wrapper is not a callable")
         
         db = cls.get_db()
-        return db.view(view_name, wrapper=wrapper, **params)
+        if view_type == 'view':
+            return db.view(data, wrapper=wrapper, **params)
+        elif view_type == 'temp_view':
+            return db.temp_view(data, wrapper=wrapper, **params)    
+        else:
+            raise RuntimeError("bad view_type : %s" % view_type )
+            
+    @classmethod
+    def view(cls, view_name, wrapper=None, dynamic_properties=True, 
+    **params):
+        """ Get documents associated to a view.
+        Results of view are automatically wrapped
+        to Document object.
+
+        :params view_name: str, name of view
+        :params params:  params of view
+
+        :return: :class:`simplecouchdb.core.ViewResults` instance. All
+        results are wrapped to current document instance.
+        """
+        return cls.__view(view_type="view", data=view_name, wrapper=wrapper, 
+            dynamic_properties=dynamic_properties, **params) 
         
     @classmethod
-    def temp_view(cls, design, wrapper=None, **params):
+    def temp_view(cls, design, wrapper=None, dynamic_properties=True, 
+    **params):
         """ Slow view. Like in view method,
         results are automatically wrapped to 
         Document object.
@@ -559,26 +594,11 @@ class QueryMixin(object):
         :params design: design object, See `simplecouchd.client.Database`
         :params params:  params of view
 
-        :return: Like view, return a :class:`simplecouchdb.core.ViewResults` instance. All
-        results are wrapped to current document instance.
+        :return: Like view, return a :class:`simplecouchdb.core.ViewResults` 
+        instance. All results are wrapped to current document instance.
         """
-        def default_wrapper(row):
-            data = row['value']
-            if not data or data is None:
-                doc = row.get('doc', False)
-                if doc:
-                    return cls.wrap(doc)
-                return row
-            data['_id'] = row.get('id')
-            obj = cls.wrap(data)
-            return obj
-        if wrapper is None:
-            wrapper = default_wrapper
-        if not callable(wrapper):
-            raise TypeError("wrapper is not a callable")
-            
-        db = cls.get_db()
-        return db.temp_view(design, wrapper=wrapper, **params)    
+        return cls.__view(view_type="temp_view", data=design, wrapper=wrapper, 
+            dynamic_properties=dynamic_properties, **params) 
         
 class Document(DocumentBase, QueryMixin, AttachmentMixin):
     """
@@ -586,4 +606,10 @@ class Document(DocumentBase, QueryMixin, AttachmentMixin):
     
     :class:`QueryMixin` for view & temp_view that wrap results to this object
     :class `AttachmentMixin` for attachments function
-    """ 
\ No newline at end of file
+    """ 
+
+class StaticDocument(Document):
+    """
+    Shorthand for a document that disallow dynamic properties.
+    """
+    _allow_dynamic_properties = False
