@@ -44,6 +44,21 @@ class ClientServerTestCase(unittest.TestCase):
         all_dbs = self.Server.all_dbs()
         self.assert_('couchdbkit_test' in all_dbs)
         del self.Server['couchdbkit_test']
+
+    def testGetOrCreateDb(self):
+        # create the database
+        self.assertFalse("get_or_create_db" in self.Server)
+        gocdb = self.Server.get_or_create_db("get_or_create_db")
+        self.assert_(gocdb.dbname == "get_or_create_db")
+        self.assert_("get_or_create_db" in self.Server)
+        self.Server.delete_db("get_or_create_db")
+        # get the database (already created)
+        self.assertFalse("get_or_create_db" in self.Server)
+        db = self.Server.create_db("get_or_create_db")
+        self.assert_("get_or_create_db" in self.Server)
+        gocdb = self.Server.get_or_create_db("get_or_create_db")
+        self.assert_(db.dbname == gocdb.dbname)
+        self.Server.delete_db("get_or_create_db")
         
     def testBadResourceClassType(self):
         self.assertRaises(TypeError, Server, resource_class=None)
@@ -171,6 +186,33 @@ class ClientDatabaseTestCase(unittest.TestCase):
             doc = db.get('http:%2F%2Fa')
         self.assertRaises(ResourceNotFound, not_found)
         del self.Server['couchdbkit_test']
+
+    def testFlush(self):
+        db = self.Server.create_db('couchdbkit_test')
+        doc1 = { '_id': 'test', 'string': 'test', 'number': 4 }
+        db.save_doc(doc1)
+        doc2 = { 'string': 'test', 'number': 4 }
+        db['test2'] = doc2
+        self.assert_(db.doc_exist('test'))
+        self.assert_(db.doc_exist('test2'))
+        design_doc = {
+            '_id': '_design/test',
+            'language': 'javascript',
+            'views': {
+                'all': {
+                    "map": """function(doc) { if (doc.docType == "test") { emit(doc._id, doc);
+            }}"""
+                }
+            }
+        }
+        db.save_doc(design_doc)
+        self.assert_(len(db) == 3)
+        db.flush()
+        self.assert_(len(db) == 1)
+        self.assertFalse(db.doc_exist('test'))
+        self.assertFalse(db.doc_exist('test2'))
+        self.assert_(db.doc_exist('_design/test'))
+        del self.Server['couchdbkit_test']
     
     def testDbLen(self):
         db = self.Server.create_db('couchdbkit_test')
